@@ -249,11 +249,7 @@ class S3SlstrProduct(S3Product):
 
     def _get_platform(self) -> Platform:
         """ Getter of the platform """
-        # look in the MTD to be sure
-        root, _ = self.read_mtd()
-        name = root.findtext(".//product_name")
-
-        if "SL" in name:
+        if "SL" in self.name:
             # Instrument
             self._instrument = S3Instrument.SLSTR
             sat_id = self._instrument.value
@@ -331,16 +327,8 @@ class S3SlstrProduct(S3Product):
 
     def _set_product_type(self) -> None:
         """Set products type"""
-        mtd, _ = self.read_mtd()
-
-        # Open identifier
-        try:
-            name = mtd.findtext(".//product_name")
-        except TypeError:
-            raise InvalidProductError("product_name not found in metadata !")
-
         # Product type
-        if name[7] != "1":
+        if self.name[7] != "1":
             raise InvalidTypeError("Only L1 products are used for Sentinel-3 data.")
 
         self.product_type = S3ProductType.SLSTR_RBT
