@@ -34,7 +34,7 @@ from sertit import files, strings, vectors
 from sertit.misc import ListEnum
 from shapely.geometry import Polygon
 
-from eoreader import cache, cached_property, utils
+from eoreader import cache, cached_property
 from eoreader.exceptions import InvalidProductError
 from eoreader.products.sar.sar_product import SarProduct, SarProductType
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
@@ -147,7 +147,6 @@ class CskProduct(SarProduct):
             raise InvalidProductError(
                 f"Image file (*.h5) not found in {product_path}"
             ) from ex
-        self._real_name = files.get_filename(self._img_path)
 
         # Initialization from the super class
         super().__init__(product_path, archive_path, output_path, remove_tmp)
@@ -156,15 +155,13 @@ class CskProduct(SarProduct):
         """
         Set product default resolution (in meters)
         """
-        def_res = None
-
         # Read metadata for default resolution
         try:
             root, _ = self.read_mtd()
             def_res = float(root.findtext(".//GroundRangeGeometricResolution"))
         except (InvalidProductError, TypeError):
             raise InvalidProductError(
-                "GroundRangeGeometricResolution or rowSpacing not found in metadata !"
+                "GroundRangeGeometricResolution or rowSpacing not found in metadata!"
             )
 
         return def_res
@@ -244,7 +241,7 @@ class CskProduct(SarProduct):
             # DGM_B, or SCS_B -> remove last 2 characters
             prod_type = root.findtext(".//ProductType")[:-2]
         except TypeError:
-            raise InvalidProductError("mode not found in metadata !")
+            raise InvalidProductError("mode not found in metadata!")
 
         self.product_type = CskProductType.from_value(prod_type)
 
@@ -268,14 +265,14 @@ class CskProduct(SarProduct):
         try:
             acq_mode = root.findtext(".//AcquisitionMode")
         except TypeError:
-            raise InvalidProductError("AcquisitionMode not found in metadata !")
+            raise InvalidProductError("AcquisitionMode not found in metadata!")
 
         # Get sensor mode
         self.sensor_mode = CskSensorMode.from_value(acq_mode)
 
         if not self.sensor_mode:
             raise InvalidProductError(
-                f"Invalid {self.platform.value} name: {self._real_name}"
+                f"Invalid {self.platform.value} name: {self.name}"
             )
 
     def get_datetime(self, as_datetime: bool = False) -> Union[str, datetime]:
@@ -306,9 +303,7 @@ class CskProduct(SarProduct):
             try:
                 acq_date = root.findtext(".//SceneSensingStartUTC")
             except TypeError:
-                raise InvalidProductError(
-                    "SceneSensingStartUTC not found in metadata !"
-                )
+                raise InvalidProductError("SceneSensingStartUTC not found in metadata!")
 
             # Convert to datetime
             # 2020-10-28 22:46:24.808662850
@@ -322,15 +317,26 @@ class CskProduct(SarProduct):
 
         return date
 
-    def _get_split_name(self) -> list:
+    def _get_name(self) -> str:
         """
-        Get split name (erasing empty strings in it by precaution, especially for S1 data)
+        Set product real name from metadata
 
         Returns:
-            list: Split products name
+            str: True name of the product (from metadata)
         """
-        # Use the real name
-        return utils.get_split_name(self._real_name)
+        if self.name is None:
+            # Get MTD XML file
+            root, _ = self.read_mtd()
+
+            # Open identifier
+            try:
+                name = files.get_filename(root.findtext(".//ProductName"))
+            except TypeError:
+                raise InvalidProductError("ProductName not found in metadata!")
+        else:
+            name = self.name
+
+        return name
 
     @cache
     def _read_mtd(self) -> (etree._Element, dict):
@@ -348,6 +354,6 @@ class CskProduct(SarProduct):
         Returns:
             (etree._Element, dict): Metadata XML root and its namespaces
         """
-        mtd_from_path = f"DFDN_{self._real_name}.h5.xml"
+        mtd_from_path = "DFDN_*.h5.xml"
 
         return self._read_mtd_xml(mtd_from_path)
