@@ -16,7 +16,7 @@
 # limitations under the License.
 """
 RADARSAT-2 products.
-More info `here <https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html#RADARSAT2__rs2_sfs>`_.
+More info `here <https://catalyst.earth/catalyst-system-files/help/references/gdb_r/RADARSAT-2.html#RADARSAT2__rs2_sfs>`_.
 """
 import difflib
 import logging
@@ -35,6 +35,7 @@ from sertit.vectors import WGS84
 from eoreader import cache, cached_property
 from eoreader.exceptions import InvalidProductError, InvalidTypeError
 from eoreader.products.sar.sar_product import SarProduct, SarProductType
+from eoreader.reader import Reader
 from eoreader.utils import DATETIME_FMT, EOREADER_NAME
 
 LOGGER = logging.getLogger(EOREADER_NAME)
@@ -47,7 +48,7 @@ warnings.filterwarnings("ignore", category=rasterio.errors.NotGeoreferencedWarni
 class Rs2ProductType(ListEnum):
     """
     RADARSAT-2 projection identifier.
-    Take a look `here <https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html>`_.
+    Take a look `here <https://catalyst.earth/catalyst-system-files/help/references/gdb_r/RADARSAT-2.html>`_.
     """
 
     SLC = "SLC"
@@ -82,7 +83,7 @@ class Rs2ProductType(ListEnum):
 class Rs2SensorMode(ListEnum):
     """
     RADARSAT-2 sensor mode.
-    Take a look `here <https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html>`_.
+    Take a look `here <https://catalyst.earth/catalyst-system-files/help/references/gdb_r/RADARSAT-2.html>`_.
 
     .. WARNING:: The name in the metadata may vary !
     """
@@ -155,7 +156,7 @@ class Rs2SensorMode(ListEnum):
 class Rs2Polarization(ListEnum):
     """
     RADARSAT-2 polarization mode.
-    Take a look `here <https://www.pcigeomatics.com/geomatica-help/references/gdb_r/RADARSAT-2.html#RADARSAT2__rs2_sfs>`_
+    Take a look `here <https://catalyst.earth/catalyst-system-files/help/references/gdb_r/RADARSAT-2.html#RADARSAT2__rs2_sfs>`_
     """
 
     HH = "HH"
@@ -182,7 +183,7 @@ class Rs2Product(SarProduct):
             def_res = float(root.findtext(f".//{namespace}sampledPixelSpacing"))
         except (InvalidProductError, TypeError):
             raise InvalidProductError(
-                "sampledPixelSpacing or rowSpacing not found in metadata !"
+                "sampledPixelSpacing or rowSpacing not found in metadata!"
             )
 
         return def_res
@@ -259,7 +260,7 @@ class Rs2Product(SarProduct):
         try:
             prod_type = root.findtext(f".//{namespace}productType")
         except TypeError:
-            raise InvalidProductError("mode not found in metadata !")
+            raise InvalidProductError("mode not found in metadata!")
 
         self.product_type = Rs2ProductType.from_value(prod_type)
 
@@ -332,7 +333,7 @@ class Rs2Product(SarProduct):
             try:
                 acq_date = root.findtext(f".//{namespace}rawDataStartTime")
             except TypeError:
-                raise InvalidProductError("rawDataStartTime not found in metadata !")
+                raise InvalidProductError("rawDataStartTime not found in metadata!")
 
             # Convert to datetime
             date = datetime.strptime(acq_date, "%Y-%m-%dT%H:%M:%S.%fZ")
@@ -344,6 +345,30 @@ class Rs2Product(SarProduct):
 
         return date
 
+    def _get_name(self) -> str:
+        """
+        Set product real name from metadata
+
+        Returns:
+            str: True name of the product (from metadata)
+        """
+        if self.name is None:
+            name = self.filename
+
+            # Test filename
+            reader = Reader()
+            if not reader.valid_name(name, self._get_platform()):
+                LOGGER.warning(
+                    "This RADARSAT-2 filename is not valid. "
+                    "However RADARSAT-2 files do not provide anywhere the true name of the product."
+                    "Use it with caution."
+                )
+
+        else:
+            name = self.name
+
+        return name
+
     @cache
     def _read_mtd(self) -> (etree._Element, dict):
         """
